==> cepent-0.0.5-py3-none-any.whl: cepent/process.py <==
import os
import traceback
import psycopg2
from datetime import datetime

class ProcessHandling:
    def __init__(self, usr, pwd, bd_pg, bd_port, bd_company, process_name):
        self.usr = usr
        self.pwd = pwd
        self.bd_pg = bd_pg
        self.bd_port = bd_port
        self.bd_procesos = "procesos"
        self.bd_company = bd_company
        self.process_name = process_name

    def start_process(self):

        try:
            connection = psycopg2.connect(user=self.usr,
                                          password=self.pwd,
                                          host=self.bd_pg,
                                          port=self.bd_port,
                                          database=self.bd_procesos)
            today = datetime.today().strftime('%Y-%m-%d %H:%M:%S')
            cursor = connection.cursor()
            qry_start_process = f"""
            INSERT INTO public.procesos(proceso, accion, estado, fecha, cliente, fecha_fin, tiempo_ejecucion)
            VALUES ('{proceso}', 'INICIO', 'EN EJECUCION', CURRENT_TIMESTAMP AT TIME ZONE 'America/Santiago', '{self.bd_company}', null, null);
        """
        
            cursor.execute(qry_start_process)
            connection.commit()
        except psycopg2.Error as e:
            print("Error while connecting to PostgreSQL", e)
        finally:
            if 'connection' in locals():
                cursor.close()

    def end_process_log(self):

        try:
            connection = psycopg2.connect(user=self.usr,
                                          password=self.pwd,
                                          host=self.bd_pg,
                                          port=self.bd_port,
                                          database=self.bd_procesos)
            today = datetime.today().strftime('%Y-%m-%d %H:%M:%S')
            cursor = connection.cursor()
            qry_end_process = f"""                 
            update procesos
            set accion ='FINALIZADO CORRECTAMENTE'
            ,fecha_fin = CURRENT_TIMESTAMP AT TIME ZONE 'America/Santiago'
            ,estado = 'OK'
            ,tiempo_ejecucion = AGE(CURRENT_TIMESTAMP AT TIME ZONE 'America/Santiago',fecha)
            WHERE proceso ='{self.process_name}'
            and fecha::date = current_date::date
            and cliente = '{self.bd_company}'
            AND id = ( select max(id) from procesos where proceso ='{self.process_name}'
            and fecha::date = current_date::date
            and cliente = '{self.bd_company}')"""
            
            cursor.execute(qry_end_process)
            connection.commit()
        except psycopg2.Error as e:
            print("Error while connecting to PostgreSQL", e)
        finally:
            if 'connection' in locals():
                cursor.close()
                
                

    def handle_error(self, table_name):
        outdir_error = './errors/'
        if not os.path.exists(outdir_error):
            os.mkdir(outdir_error)
        
        tb = traceback.format_exc()
        with open(f'{outdir_error}/{table_name}.txt', 'w') as f:
            f.write(tb)

        try:
            connection = psycopg2.connect(user=self.usr,
                                          password=self.pwd,
                                          host=self.bd_pg,
                                          port=self.bd_port,
                                          database=self.bd_procesos)
            
            cursor = connection.cursor()
            qry_add_data_comp_net_final = f"""
                    update procesos
                    set accion ='ERROR {table_name}'
                    ,fecha_fin = CURRENT_TIMESTAMP AT TIME ZONE 'America/Santiago'
                    ,estado = 'ERROR'
                    ,tiempo_ejecucion = AGE(CURRENT_TIMESTAMP AT TIME ZONE 'America/Santiago',fecha)
                    WHERE proceso ='{self.process_name.upper()}'
                    and fecha::date = current_date::date
                    and cliente = '{self.bd_company.upper()}'
                    AND id = ( select max(id) from procesos where proceso ='{self.process_name.upper()}'
                    and fecha::date = current_date::date
                    and cliente = '{self.bd_company}')
                    """
            cursor.execute(qry_add_data_comp_net_final)
            
            connection.commit()
        except psycopg2.Error as e:
            print("Error while connecting to PostgreSQL", e)
        finally:
            if 'connection' in locals():
                cursor.close()

==> cepent-0.0.7-py3-none-any.whl: cepent/process.py <==
import os
import traceback
import psycopg2
from datetime import datetime

class ProcessHandling:
    def __init__(self, usr, pwd, bd_pg, bd_port, bd_company, process_name):
        self.usr = usr
        self.pwd = pwd
        self.bd_pg = bd_pg
        self.bd_port = bd_port
        self.bd_procesos = "procesos"
        self.bd_company = bd_company
        self.process_name = process_name

    def start_process_log(self):

        try:
            connection = psycopg2.connect(user=self.usr,
                                          password=self.pwd,
                                          host=self.bd_pg,
                                          port=self.bd_port,
                                          database=self.bd_procesos)
            today = datetime.today().strftime('%Y-%m-%d %H:%M:%S')
            cursor = connection.cursor()
            qry_start_process = f"""
            INSERT INTO public.procesos(proceso, accion, estado, fecha, cliente, fecha_fin, tiempo_ejecucion)
            VALUES ('{self.process_name}', 'INICIO', 'EN EJECUCION', CURRENT_TIMESTAMP AT TIME ZONE 'America/Santiago', '{self.bd_company}', null, null);
        """
        
            cursor.execute(qry_start_process)
            connection.commit()
        except psycopg2.Error as e:
            print("Error while connecting to PostgreSQL", e)
        finally:
            if 'connection' in locals():
                cursor.close()

    def end_process_log(self):

        try:
            connection = psycopg2.connect(user=self.usr,
                                          password=self.pwd,
                                          host=self.bd_pg,
                                          port=self.bd_port,
                                          database=self.bd_procesos)
            today = datetime.today().strftime('%Y-%m-%d %H:%M:%S')
            cursor = connection.cursor()
            qry_end_process = f"""                 
            update procesos
            set accion ='FINALIZADO CORRECTAMENTE'
            ,fecha_fin = CURRENT_TIMESTAMP AT TIME ZONE 'America/Santiago'
            ,estado = 'OK'
            ,tiempo_ejecucion = AGE(CURRENT_TIMESTAMP AT TIME ZONE 'America/Santiago',fecha)
            WHERE proceso ='{self.process_name}'
            and fecha::date = current_date::date
            and cliente = '{self.bd_company}'
            AND id = ( select max(id) from procesos where proceso ='{self.process_name}'
            and fecha::date = current_date::date
            and cliente = '{self.bd_company}')"""
            
            cursor.execute(qry_end_process)
            connection.commit()
        except psycopg2.Error as e:
            print("Error while connecting to PostgreSQL", e)
        finally:
            if 'connection' in locals():
                cursor.close()
                
                

    def handle_error_log(self, table_name):
        outdir_error = './errors/'
        if not os.path.exists(outdir_error):
            os.mkdir(outdir_error)
        
        tb = traceback.format_exc()
        with open(f'{outdir_error}/{table_name}.txt', 'w') as f:
            f.write(tb)

        try:
            connection = psycopg2.connect(user=self.usr,
                                          password=self.pwd,
                                          host=self.bd_pg,
                                          port=self.bd_port,
                                          database=self.bd_procesos)
            
            cursor = connection.cursor()
            qry_add_data_comp_net_final = f"""
                    update procesos
                    set accion ='ERROR {table_name}'
                    ,fecha_fin = CURRENT_TIMESTAMP AT TIME ZONE 'America/Santiago'
                    ,estado = 'ERROR'
                    ,tiempo_ejecucion = AGE(CURRENT_TIMESTAMP AT TIME ZONE 'America/Santiago',fecha)
                    WHERE proceso ='{self.process_name.upper()}'
                    and fecha::date = current_date::date
                    and cliente = '{self.bd_company.upper()}'
                    AND id = ( select max(id) from procesos where proceso ='{self.process_name.upper()}'
                    and fecha::date = current_date::date
                    and cliente = '{self.bd_company}')
                    """
            cursor.execute(qry_add_data_comp_net_final)
            
            connection.commit()
        except psycopg2.Error as e:
            print("Error while connecting to PostgreSQL", e)
        finally:
            if 'connection' in locals():
                cursor.close()
